/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { FloorScene } from "./FloorScene";
import { MarkerItem } from "./items/MarkItem";
import { Marker } from "./types/Marker";

/**
 * 位置标签绘制标志
 *
 * @author 郝建龙
 */
export class LocationPointScene extends FloorScene {
    /** 标志list    */
    markerList: MarkerItem[] = [];
    /** 标志是否可选  */
    _isMarkSelectable: boolean = true;
    get isMarkSelectable(): boolean {
        return this._isMarkSelectable;
    } // Get isMarkSelectable
    set isMarkSelectable(v: boolean) {
        if (this._isMarkSelectable === v) {
            return;
        }
        this._isMarkSelectable = v;
        this.markerList.map((t: MarkerItem) => {
            t.selectable = this._isMarkSelectable;
            return t;
        });
    } // Set isMarkSelectable

    /**
     * 构造函数
     *
     */
    constructor() {
        super();
    } // Constructor

    /**
     * 添加标志list至scene中
     *
     * @param   markerList  标志对象list
     */
    addMarkerList(markerList: Marker[]): void {
        markerList.map(t => {
            this.addMarker(t);
        });
    } // Function addMarkerList()

    /**
     * 添加标志到scene中
     *
     * @param   marker  标志对象
     */
    addMarker(marker: Marker): void {
        let mark = new MarkerItem(null, marker);
        mark.moveTo(marker.X, marker.Y);
        mark.selectable = this.isMarkSelectable;
        this.markerList.push(mark);
        this.addItem(mark);
    } // Function addMarker()

    /**
     * 标志的点击事件
     *
     * @param   _this    接收者
     * @param   fn       处理函数
     */
    markerClick(_this: any, fn: Function): void {
        this.markerList.map(m => {
            m.connect("click", _this, fn);
        });
    } // Function markerClick()

    /**
     * 空间的点击事件
     *
     * @param   _this    接收者
     * @param   fn       处理函数
     */
    spaceClick(_this: any, fn: Function) {
        this.spaceList.map(m => {
            m.connect("click", _this, fn);
        });
    } // Function spaceClick()
} // Class LocationPointScene
